durationtools.Offset
====================

.. abjad-lineage:: abjad.tools.durationtools.Offset.Offset

.. autoclass:: abjad.tools.durationtools.Offset.Offset

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.durationtools.Offset.Offset.conjugate
      ~abjad.tools.durationtools.Offset.Offset.denominator
      ~abjad.tools.durationtools.Offset.Offset.dot_count
      ~abjad.tools.durationtools.Offset.Offset.durations_to_nonreduced_fractions
      ~abjad.tools.durationtools.Offset.Offset.equal_or_greater_assignable
      ~abjad.tools.durationtools.Offset.Offset.equal_or_greater_power_of_two
      ~abjad.tools.durationtools.Offset.Offset.equal_or_lesser_assignable
      ~abjad.tools.durationtools.Offset.Offset.equal_or_lesser_power_of_two
      ~abjad.tools.durationtools.Offset.Offset.flag_count
      ~abjad.tools.durationtools.Offset.Offset.from_decimal
      ~abjad.tools.durationtools.Offset.Offset.from_float
      ~abjad.tools.durationtools.Offset.Offset.from_lilypond_duration_string
      ~abjad.tools.durationtools.Offset.Offset.has_power_of_two_denominator
      ~abjad.tools.durationtools.Offset.Offset.imag
      ~abjad.tools.durationtools.Offset.Offset.implied_prolation
      ~abjad.tools.durationtools.Offset.Offset.is_assignable
      ~abjad.tools.durationtools.Offset.Offset.is_token
      ~abjad.tools.durationtools.Offset.Offset.lilypond_duration_string
      ~abjad.tools.durationtools.Offset.Offset.limit_denominator
      ~abjad.tools.durationtools.Offset.Offset.numerator
      ~abjad.tools.durationtools.Offset.Offset.pair
      ~abjad.tools.durationtools.Offset.Offset.prolation_string
      ~abjad.tools.durationtools.Offset.Offset.real
      ~abjad.tools.durationtools.Offset.Offset.reciprocal
      ~abjad.tools.durationtools.Offset.Offset.to_clock_string
      ~abjad.tools.durationtools.Offset.Offset.with_denominator
      ~abjad.tools.durationtools.Offset.Offset.yield_durations
      ~abjad.tools.durationtools.Offset.Offset.yield_equivalent_durations
      ~abjad.tools.durationtools.Offset.Offset.__abs__
      ~abjad.tools.durationtools.Offset.Offset.__add__
      ~abjad.tools.durationtools.Offset.Offset.__complex__
      ~abjad.tools.durationtools.Offset.Offset.__copy__
      ~abjad.tools.durationtools.Offset.Offset.__deepcopy__
      ~abjad.tools.durationtools.Offset.Offset.__div__
      ~abjad.tools.durationtools.Offset.Offset.__divmod__
      ~abjad.tools.durationtools.Offset.Offset.__eq__
      ~abjad.tools.durationtools.Offset.Offset.__float__
      ~abjad.tools.durationtools.Offset.Offset.__floordiv__
      ~abjad.tools.durationtools.Offset.Offset.__format__
      ~abjad.tools.durationtools.Offset.Offset.__ge__
      ~abjad.tools.durationtools.Offset.Offset.__gt__
      ~abjad.tools.durationtools.Offset.Offset.__hash__
      ~abjad.tools.durationtools.Offset.Offset.__le__
      ~abjad.tools.durationtools.Offset.Offset.__lt__
      ~abjad.tools.durationtools.Offset.Offset.__mod__
      ~abjad.tools.durationtools.Offset.Offset.__mul__
      ~abjad.tools.durationtools.Offset.Offset.__ne__
      ~abjad.tools.durationtools.Offset.Offset.__neg__
      ~abjad.tools.durationtools.Offset.Offset.__new__
      ~abjad.tools.durationtools.Offset.Offset.__nonzero__
      ~abjad.tools.durationtools.Offset.Offset.__pos__
      ~abjad.tools.durationtools.Offset.Offset.__pow__
      ~abjad.tools.durationtools.Offset.Offset.__radd__
      ~abjad.tools.durationtools.Offset.Offset.__rdiv__
      ~abjad.tools.durationtools.Offset.Offset.__rdivmod__
      ~abjad.tools.durationtools.Offset.Offset.__repr__
      ~abjad.tools.durationtools.Offset.Offset.__rfloordiv__
      ~abjad.tools.durationtools.Offset.Offset.__rmod__
      ~abjad.tools.durationtools.Offset.Offset.__rmul__
      ~abjad.tools.durationtools.Offset.Offset.__rpow__
      ~abjad.tools.durationtools.Offset.Offset.__rsub__
      ~abjad.tools.durationtools.Offset.Offset.__rtruediv__
      ~abjad.tools.durationtools.Offset.Offset.__str__
      ~abjad.tools.durationtools.Offset.Offset.__sub__
      ~abjad.tools.durationtools.Offset.Offset.__truediv__
      ~abjad.tools.durationtools.Offset.Offset.__trunc__

Bases
-----

- :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`fractions.Fraction <fractions.Fraction>`

- :py:class:`numbers.Rational <numbers.Rational>`

- :py:class:`numbers.Real <numbers.Real>`

- :py:class:`numbers.Complex <numbers.Complex>`

- :py:class:`numbers.Number <numbers.Number>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.dot_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.equal_or_greater_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.equal_or_greater_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.equal_or_lesser_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.equal_or_lesser_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.flag_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.imag
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.is_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.lilypond_duration_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.numerator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.pair
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.prolation_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.real
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.reciprocal
   :noindex:

Methods
-------

.. automethod:: abjad.tools.durationtools.Offset.Offset.conjugate
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.limit_denominator
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.to_clock_string
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.with_denominator
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.yield_equivalent_durations
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.from_decimal
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.from_float
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.durations_to_nonreduced_fractions
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.from_lilypond_duration_string
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.is_token
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.yield_durations
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.__abs__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__add__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__complex__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__copy__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__div__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__divmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__eq__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__float__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__floordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__format__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__ge__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__gt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__hash__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__le__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__lt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__mod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__mul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__ne__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__neg__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__new__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__nonzero__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__pos__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__pow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__radd__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rdiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rdivmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__repr__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rfloordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rmul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rpow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rsub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__rtruediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__str__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__sub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__truediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.__trunc__
   :noindex:
